<?php

namespace XenGenTr\XenOneCikanKonular\Entity;

use XF\Mvc\Entity\Structure;

class Onecikan extends \XF\Mvc\Entity\Entity
{
	public function canEdit()
	{
		$thread = $this->Thread;
		$visitor = \XF::visitor();
		
		if ($visitor->hasPermission('OneCikanKonular_izinler', 'onecikan_yonet'))
		{
			return true;
		}
		
		if ($visitor->hasPermission('OneCikanKonular_izinler', 'onecikan_gonder')
			&& $visitor->user_id == $thread->user_id)
		{
			return true;
		}
		
		return false;
	}
	
	public function getImage()
	{
		$image = \XF::getRootDirectory() . '/data/onecikan_konular/' . $this->thread_id . '.jpg';
		
		if (file_exists($image))
		{
			return 'data/onecikan_konular/' . $this->thread_id . '.jpg?' . $this->onecikan_saat;
		}
	
		return "styles/XenGenTr/xengentr_onecikankonular/varsayilan_ikon.png";
	}
	
	protected function _preSave()
	{
		$this->onecikan_saat = \XF::$time;
	}
	
	protected function _postDelete()
	{
		$image = \XF::getRootDirectory() . '/data/onecikan_konular/' . $this->thread_id . '.jpg';
		if (file_exists($image)) { unlink($image); }
	}
	
	public static function getStructure(Structure $structure)
	{
		$structure->table = 'xengentr_onecikanlar';
		$structure->shortName = 'XenGenTr\XenOneCikanKonular:Onecikan';
		$structure->primaryKey = 'thread_id';
		$structure->columns = [
			'thread_id' =>				['type' => self::UINT, 'required' => true],
			'onecikan_tarih' =>			['type' => self::UINT, 'required' => true],
			'onecikan_saat' =>			['type' => self::UINT, 'required' => true],
			'onecikan_baslik' =>	    ['type' => self::STR, 'required' => false, 'default' => ''],
			'onecikan_icerik' =>		['type' => self::STR, 'required' => false, 'default' => ''],
			'onecikan_medya' =>			['type' => self::STR, 'required' => false, 'default' => ''],
		];
		$structure->getters = [
			'image' => true,
		];

		$structure->relations = [
			'Thread' => [
				'entity' => 'XF:Thread',
				'type' => self::TO_ONE,
				'conditions' => 'thread_id',
				'primary' => true,
			],
		];

		return $structure;
	}
}